library(phyloseq)
library(vegan)
library(tsne)

#ENVFIT statistics (p-value for contribution of metadata to ordination clustering)
#---------------------------------------------
md <- read.table(file="/Users/tommyauchtung/Desktop/MP139_SUPERMETADATA.txt", header = TRUE, sep = "\t")

#To subset by age
md3to6 <- subset(md, ExactAgeinMonths >= 3 & ExactAgeinMonths < 6)
md3to6 <- plyr::ddply(md3to6, 'SubjectMaskId', head, n=1)
md7to10 <- subset(md, ExactAgeinMonths >= 7 & ExactAgeinMonths < 10)
md7to10 <- plyr::ddply(md7to10, 'SubjectMaskId', head, n=1)
md11to14 <- subset(md, ExactAgeinMonths >= 11 & ExactAgeinMonths < 14)
md11to14 <- plyr::ddply(md11to14, 'SubjectMaskId', head, n=1)
md15to18 <- subset(md, ExactAgeinMonths >= 15 & ExactAgeinMonths < 18)
md15to18 <- plyr::ddply(md15to18, 'SubjectMaskId', head, n=1)
md19to22 <- subset(md, ExactAgeinMonths >= 19 & ExactAgeinMonths < 22)
md19to22 <- plyr::ddply(md19to22, 'SubjectMaskId', head, n=1)
md23to26 <- subset(md, ExactAgeinMonths >= 23 & ExactAgeinMonths < 26)
md23to26 <- plyr::ddply(md23to26, 'SubjectMaskId', head, n=1)
md27to30 <- subset(md, ExactAgeinMonths >= 27 & ExactAgeinMonths < 30)
md27to30 <- plyr::ddply(md27to30, 'SubjectMaskId', head, n=1)
md31to34 <- subset(md, ExactAgeinMonths >= 31 & ExactAgeinMonths < 34)
md31to34 <- plyr::ddply(md31to34, 'SubjectMaskId', head, n=1)
md35to39 <- subset(md, ExactAgeinMonths >= 35 & ExactAgeinMonths < 39)
md35to39 <- plyr::ddply(md35to39, 'SubjectMaskId', head, n=1)
md40plus <- subset(md, ExactAgeinMonths >= 40)
md40plus <- plyr::ddply(md40plus, 'SubjectMaskId', head, n=1)

dir.create("/Users/tommyauchtung/Desktop/envfit/")

#Do this for each age group, e.g.:
custom_age_md <- md3to6

####################### Determine Ordination Coordinates ###########################
# Set these paths before beginning
biom.FilePath <- "/Users/tommyauchtung/Desktop/OTU_Table.Merged.97.JustFungi.ForExport.biom"

# Read in the OTU table
phylo <- import_biom( biom.FilePath, 
                      parallel = TRUE,
                      parseFunction = function(x){
                        x <- gsub("^[\ _]+", "", x)
                        x <- gsub("[\ ]+$",  "", x)
                        names(x) <- c("Kingdom", "Phylum", "Class", "Order", "Family", "Genus", "Species", "Strain")[1:length(x)]
                        return(x)
                      })

# Rarefy
phylorare <- rarefy_even_depth(phylo, 3000, replace=FALSE)

# Make distance matrices
DistanceMatrixBray <- distance(phylorare, method="bray", binary=FALSE)
DistanceMatrixSorensen <- distance(phylorare, method="bray", binary=TRUE)

#PCoA:
OrdinationBrayPCoA     <- ordinate(phylorare, "PCoA", distance=DistanceMatrixBray)
write.table(OrdinationBrayPCoA, "/Users/tommyauchtung/Desktop/CoordsBrayPCoA.txt")
OrdinationSorensenPCoA     <- ordinate(phylorare, "PCoA", distance=DistanceMatrixSorensen)
write.table(OrdinationSorensenPCoA, "/Users/tommyauchtung/Desktop/CoordsSorensenPCoA.txt")

#t-SNE
OrdinationBrayTsne <- tsne(DistanceMatrixBray, k=2)
write.table(OrdinationBrayTsne, "/Users/tommyauchtung/Desktop/CoordsOrdinationBrayTsne.txt")
OrdinationSorensenTsne <- tsne(DistanceMatrixSorensen, k=2)
write.table(OrdinationSorensenTsne, "/Users/tommyauchtung/Desktop/CoordsOrdinationSorensenTsne.txt")

############################## PCoA Envfit ################################
#PCoA Bray
(fit1 <- envfit(custom_age_md[c('AvgCorrBrayPCoA.Axis1','AvgCorrBrayPCoA.Axis2')], custom_age_md[,c('ObsFungiR3K.Cat','ShanFungiR3K.Cat','Obs16SR3K.Cat','Shan16SR3K.Cat','DMM','WhereFamilyLives','Clinical.Center','Clinical.Country','Continent','Sex','Gest.Age.Rough','BabysLengthCat','BabysWeightClass','ApgarClass','PreEclampsiaOrToxemia','Birth.Mode','Birth.Mode.Simple','Birth.Season','FdrName','HLA.CategoryLong','IA.OutcomeYesNo','T1D.OutcomeYesNo','ProbioticsFive','EverProbioticsYesNo','AbxTenState','AbxName','Amoxicillin','InfEpTen','InfEpTenFever','BothInfFev','SpecialDiets','JustCowsMilkAvoidance','JustVegetarian','JustCerealOrWheatAvoidanceOrGlutenFree','Breastfeeding','formula.any','first.form.process','formula.cows.milk','formula.soy','formula.probiotic','formula.prebiotic','apple.sauce.or.apple.juice','fruit.or.berries','potatoes','sweet.potatoes.or.yams','carrots','spinach','beets','peas.green.beans','turnip.parsnip.artichoke.rutabag','cabbages','squash.pumpkin','tomato.or.tomato.sauce','corn','other.vegetable','rice','wheat','barley','oat','rye','buckwheat.and.millet','other.fib01','other.fib02','other.fib03','other.fib04','other.fib05','other.fib06','other.fib07','other.fib08','other.fib09','other.fib10','other.fib11','other.fib12','other.fib13','pork.beef','poultry','other.kinds.of.meat','sausage.hot.dogs','fish.or.other.seafood','egg','milk.products','regular.cow.s.milk.or.ice.cream','commercial.baby.food.containing','soy.milk.and.other.soy.products','rice.milk','goat.milk','gluten','cereals','gluten.cereals','nongluten.cereals','noncorn.cereals','nongluten.noncorn.cereals','rice.ricemilk','fruits.and.berries','root.vegetables','total.roots','milk.product','cow.milk.any','soy','cow.milk.nof','fibtime','child.a1','child.a2','child.a3','child.a4','child.a5','child.a6','child.a7','child.a8','child.a9','child.a10','child.a11','child.a12','child.a13','child.a14','child.a15','child.a16','child.a17','child.a18','child.a19','child.a20','child.a21','child.a22','child.a23','child.a24','child.a25','child.a26','child.a27','child.b1','child.b2','child.b3','child.b4','child.b5','child.b6','child.b7','child.b8','child.b9','child.b10','random.Cat'),drop=FALSE], perm = 9999, na.rm = TRUE))
(fit2 <- envfit(custom_age_md[c('AvgCorrBrayPCoA.Axis1','AvgCorrBrayPCoA.Axis2')], custom_age_md[,c('mean.s.protein.Cat','mean.f.protein.Cat','mean.protein.Cat','mean.s.nitro.Cat','mean.f.nitro.Cat','mean.nitro.Cat','mean.s.fat.Cat','mean.f.fat.Cat','mean.fat.Cat','mean.s.safa.Cat','mean.f.safa.Cat','mean.safa.Cat','mean.s.butanoic.Cat','mean.f.butanoic.Cat','mean.butanoic.Cat','mean.s.hexanoic.Cat','mean.f.hexanoic.Cat','mean.hexanoic.Cat','mean.s.octanoic.Cat','mean.f.octanoic.Cat','mean.octanoic.Cat','mean.s.decanoic.Cat','mean.f.decanoic.Cat','mean.decanoic.Cat','mean.s.lauric.Cat','mean.f.lauric.Cat','mean.lauric.Cat','mean.s.myristic.Cat','mean.f.myristic.Cat','mean.myristic.Cat','mean.s.palmitic.Cat','mean.f.palmitic.Cat','mean.palmitic.Cat','mean.s.stearic.Cat','mean.f.stearic.Cat','mean.stearic.Cat','mean.s.arachidic.Cat','mean.f.arachidic.Cat','mean.arachidic.Cat','mean.s.mufa.Cat','mean.f.mufa.Cat','mean.mufa.Cat','mean.s.palmitoleic.Cat','mean.f.palmitoleic.Cat','mean.palmitoleic.Cat','mean.s.oleic.Cat','mean.f.oleic.Cat','mean.oleic.Cat','mean.s.pufa.Cat','mean.f.pufa.Cat','mean.pufa.Cat','mean.s.linoleic.Cat','mean.f.linoleic.Cat','mean.linoleic.Cat','mean.s.linolenic.Cat','mean.f.linolenic.Cat','mean.linolenic.Cat','mean.s.linolenic.n3.Cat','mean.f.linolenic.n3.Cat','mean.linolenic.n3.Cat','mean.s.arachidonic.Cat','mean.f.arachidonic.Cat','mean.arachidonic.Cat','mean.s.eico.Cat','mean.f.eico.Cat','mean.eico.Cat','mean.s.dpa.Cat','mean.f.dpa.Cat','mean.dpa.Cat','mean.s.dha.Cat','mean.f.dha.Cat','mean.dha.Cat','mean.s.chol.Cat','mean.f.chol.Cat','mean.chol.Cat','mean.s.carb.Cat','mean.f.carb.Cat','mean.carb.Cat','mean.s.sugar.Cat','mean.f.sugar.Cat','mean.sugar.Cat','mean.s.starch.Cat','mean.f.starch.Cat','mean.starch.Cat','mean.s.fiber.Cat','mean.f.fiber.Cat','mean.fiber.Cat','mean.s.betacar.Cat','mean.f.betacar.Cat','mean.betacar.Cat','mean.s.reteq.Cat','mean.f.reteq.Cat','mean.reteq.Cat','mean.s.retaeq.Cat','mean.f.retaeq.Cat','mean.retaeq.Cat','mean.s.vitd.Cat','mean.f.vitd.Cat','mean.vitd.Cat','mean.s.vite.Cat','mean.f.vite.Cat','mean.vite.Cat','mean.s.vite.tot.Cat','mean.f.vite.tot.Cat','mean.vite.tot.Cat','mean.s.vitk.Cat','mean.f.vitk.Cat','mean.vitk.Cat','mean.s.vitc.Cat','mean.f.vitc.Cat','mean.vitc.Cat','mean.s.thiamin.Cat','mean.f.thiamin.Cat','mean.thiamin.Cat','mean.s.riboflavin.Cat','mean.f.riboflavin.Cat','mean.riboflavin.Cat','mean.s.niacin.Cat','mean.f.niacin.Cat','mean.niacin.Cat','mean.s.folate.Cat','mean.f.folate.Cat','mean.folate.Cat','mean.s.pyridoxine.Cat','mean.f.pyridoxine.Cat','mean.pyridoxine.Cat','mean.s.pantothenic.Cat','mean.f.pantothenic.Cat','mean.pantothenic.Cat','mean.s.vitb12.Cat','mean.f.vitb12.Cat','mean.vitb12.Cat','mean.s.calcium.Cat','mean.f.calcium.Cat','mean.calcium.Cat','mean.s.phos.Cat','mean.f.phos.Cat','mean.phos.Cat','mean.s.potassium.Cat','mean.f.potassium.Cat','mean.potassium.Cat','mean.s.mag.Cat','mean.f.mag.Cat','mean.mag.Cat','mean.s.mang.Cat','mean.f.mang.Cat','mean.mang.Cat','mean.s.iron.Cat','mean.f.iron.Cat','mean.iron.Cat','mean.s.zinc.Cat','mean.f.zinc.Cat','mean.zinc.Cat','mean.s.copper.Cat','mean.f.copper.Cat','mean.copper.Cat','mean.energy.Cat'),drop=FALSE], perm = 9999, na.rm = TRUE))
#all categories doesn't work so need to split in half (fit <- envfit(custom_age_md[c('AvgCorrBrayPCoA.Axis1','AvgCorrBrayPCoA.Axis2')], custom_age_md[,c('ObsFungiR3K.Cat','ShanFungiR3K.Cat','Obs16SR3K.Cat','Shan16SR3K.Cat','DMM','WhereFamilyLives','Clinical.Center','Clinical.Country','Continent','Sex','Gest.Age.Rough','BabysLengthCat','BabysWeightClass','ApgarClass','PreEclampsiaOrToxemia','Birth.Mode','Birth.Mode.Simple','Birth.Season','FdrName','HLA.CategoryLong','IA.OutcomeYesNo','T1D.OutcomeYesNo','ProbioticsFive','EverProbioticsYesNo','AbxTenState','AbxName','Amoxicillin','InfEpTen','InfEpTenFever','BothInfFev','SpecialDiets','JustCowsMilkAvoidance','JustVegetarian','JustCerealOrWheatAvoidanceOrGlutenFree','Breastfeeding','formula.any','first.form.process','formula.cows.milk','formula.soy','formula.probiotic','formula.prebiotic','apple.sauce.or.apple.juice','fruit.or.berries','potatoes','sweet.potatoes.or.yams','carrots','spinach','beets','peas.green.beans','turnip.parsnip.artichoke.rutabag','cabbages','squash.pumpkin','tomato.or.tomato.sauce','corn','other.vegetable','rice','wheat','barley','oat','rye','buckwheat.and.millet','other.fib01','other.fib02','other.fib03','other.fib04','other.fib05','other.fib06','other.fib07','other.fib08','other.fib09','other.fib10','other.fib11','other.fib12','other.fib13','pork.beef','poultry','other.kinds.of.meat','sausage.hot.dogs','fish.or.other.seafood','egg','milk.products','regular.cow.s.milk.or.ice.cream','commercial.baby.food.containing','soy.milk.and.other.soy.products','rice.milk','goat.milk','gluten','cereals','gluten.cereals','nongluten.cereals','noncorn.cereals','nongluten.noncorn.cereals','rice.ricemilk','fruits.and.berries','root.vegetables','total.roots','milk.product','cow.milk.any','soy','cow.milk.nof','fibtime','child.a1','child.a2','child.a3','child.a4','child.a5','child.a6','child.a7','child.a8','child.a9','child.a10','child.a11','child.a12','child.a13','child.a14','child.a15','child.a16','child.a17','child.a18','child.a19','child.a20','child.a21','child.a22','child.a23','child.a24','child.a25','child.a26','child.a27','child.b1','child.b2','child.b3','child.b4','child.b5','child.b6','child.b7','child.b8','child.b9','child.b10','mean.s.protein.Cat','mean.f.protein.Cat','mean.protein.Cat','mean.s.nitro.Cat','mean.f.nitro.Cat','mean.nitro.Cat','mean.s.fat.Cat','mean.f.fat.Cat','mean.fat.Cat','mean.s.safa.Cat','mean.f.safa.Cat','mean.safa.Cat','mean.s.butanoic.Cat','mean.f.butanoic.Cat','mean.butanoic.Cat','mean.s.hexanoic.Cat','mean.f.hexanoic.Cat','mean.hexanoic.Cat','mean.s.octanoic.Cat','mean.f.octanoic.Cat','mean.octanoic.Cat','mean.s.decanoic.Cat','mean.f.decanoic.Cat','mean.decanoic.Cat','mean.s.4.10sfa.Cat','mean.f.4.10sfa.Cat','mean.4.10sfa.Cat','mean.s.lauric.Cat','mean.f.lauric.Cat','mean.lauric.Cat','mean.s.myristic.Cat','mean.f.myristic.Cat','mean.myristic.Cat','mean.s.palmitic.Cat','mean.f.palmitic.Cat','mean.palmitic.Cat','mean.s.stearic.Cat','mean.f.stearic.Cat','mean.stearic.Cat','mean.s.arachidic.Cat','mean.f.arachidic.Cat','mean.arachidic.Cat','mean.s.mufa.Cat','mean.f.mufa.Cat','mean.mufa.Cat','mean.s.palmitoleic.Cat','mean.f.palmitoleic.Cat','mean.palmitoleic.Cat','mean.s.oleic.Cat','mean.f.oleic.Cat','mean.oleic.Cat','mean.s.pufa.Cat','mean.f.pufa.Cat','mean.pufa.Cat','mean.s.linoleic.Cat','mean.f.linoleic.Cat','mean.linoleic.Cat','mean.s.linolenic.Cat','mean.f.linolenic.Cat','mean.linolenic.Cat','mean.s.linolenic.n3.Cat','mean.f.linolenic.n3.Cat','mean.linolenic.n3.Cat','mean.s.arachidonic.Cat','mean.f.arachidonic.Cat','mean.arachidonic.Cat','mean.s.eico.Cat','mean.f.eico.Cat','mean.eico.Cat','mean.s.dpa.Cat','mean.f.dpa.Cat','mean.dpa.Cat','mean.s.dha.Cat','mean.f.dha.Cat','mean.dha.Cat','mean.s.chol.Cat','mean.f.chol.Cat','mean.chol.Cat','mean.s.carb.Cat','mean.f.carb.Cat','mean.carb.Cat','mean.s.sugar.Cat','mean.f.sugar.Cat','mean.sugar.Cat','mean.s.starch.Cat','mean.f.starch.Cat','mean.starch.Cat','mean.s.fiber.Cat','mean.f.fiber.Cat','mean.fiber.Cat','mean.s.betacar.Cat','mean.f.betacar.Cat','mean.betacar.Cat','mean.s.reteq.Cat','mean.f.reteq.Cat','mean.reteq.Cat','mean.s.retaeq.Cat','mean.f.retaeq.Cat','mean.retaeq.Cat','mean.s.vitd.Cat','mean.f.vitd.Cat','mean.vitd.Cat','mean.s.vite.Cat','mean.f.vite.Cat','mean.vite.Cat','mean.s.vite.tot.Cat','mean.f.vite.tot.Cat','mean.vite.tot.Cat','mean.s.vitk.Cat','mean.f.vitk.Cat','mean.vitk.Cat','mean.s.vitc.Cat','mean.f.vitc.Cat','mean.vitc.Cat','mean.s.thiamin.Cat','mean.f.thiamin.Cat','mean.thiamin.Cat','mean.s.riboflavin.Cat','mean.f.riboflavin.Cat','mean.riboflavin.Cat','mean.s.niacin.Cat','mean.f.niacin.Cat','mean.niacin.Cat','mean.s.folate.Cat','mean.f.folate.Cat','mean.folate.Cat','mean.s.pyridoxine.Cat','mean.f.pyridoxine.Cat','mean.pyridoxine.Cat','mean.s.pantothenic.Cat','mean.f.pantothenic.Cat','mean.pantothenic.Cat','mean.s.vitb12.Cat','mean.f.vitb12.Cat','mean.vitb12.Cat','mean.s.calcium.Cat','mean.f.calcium.Cat','mean.calcium.Cat','mean.s.phos.Cat','mean.f.phos.Cat','mean.phos.Cat','mean.s.potassium.Cat','mean.f.potassium.Cat','mean.potassium.Cat','mean.s.mag.Cat','mean.f.mag.Cat','mean.mag.Cat','mean.s.mang.Cat','mean.f.mang.Cat','mean.mang.Cat','mean.s.iron.Cat','mean.f.iron.Cat','mean.iron.Cat','mean.s.zinc.Cat','mean.f.zinc.Cat','mean.zinc.Cat','mean.s.copper.Cat','mean.f.copper.Cat','mean.copper.Cat','mean.energy.Cat','random.Cat'),drop=FALSE], perm = 9999, na.rm = TRUE))
#skip 'mean.s.4.10sfa.Cat','mean.f.4.10sfa.Cat','mean.4.10sfa.Cat' that somehow as a group give "Error in prod(np) : invalid 'type' (list) of argument"
#fit2 can't run with sparser datasets (md27to30 and up)

(FungiPCoABray_Pvalue <- fit1$factors$pvals) #change all "factors" to "vectors" for continuous variables
(FungiPCoABray_PvalueFDR <- p.adjust(FungiPCoABray_Pvalue, method = "fdr"))
(FungiPCoABray_r2 <- fit1$factors$r)
write.table(FungiPCoABray_Pvalue, "/Users/tommyauchtung/Desktop/envfit/FungiPCoABray_Pvalue.txt", sep="\t")
write.table(FungiPCoABray_PvalueFDR, "/Users/tommyauchtung/Desktop/envfit/FungiPCoABray_PvalueFDR.txt", sep="\t")
write.table(FungiPCoABray_r2, "/Users/tommyauchtung/Desktop/envfit/FungiPCoABray_r2.txt", sep="\t")

(FungiPCoABray_Pvalue <- fit2$factors$pvals) #change all "factors" to "vectors" for continuous variables
(FungiPCoABray_PvalueFDR <- p.adjust(FungiPCoABray_Pvalue, method = "fdr"))
(FungiPCoABray_r2 <- fit2$factors$r)
write.table(FungiPCoABray_Pvalue, "/Users/tommyauchtung/Desktop/envfit/FungiPCoABray_Pvalue_2.txt", sep="\t")
write.table(FungiPCoABray_PvalueFDR, "/Users/tommyauchtung/Desktop/envfit/FungiPCoABray_PvalueFDR_2.txt", sep="\t")
write.table(FungiPCoABray_r2, "/Users/tommyauchtung/Desktop/envfit/FungiPCoABray_r2_2.txt", sep="\t")

#PCoA Sorensen
(fit1 <- envfit(custom_age_md[c('AvgCorrSorPCoA.Axis1','AvgCorrSorPCoA.Axis2')], custom_age_md[,c('ObsFungiR3K.Cat','ShanFungiR3K.Cat','Obs16SR3K.Cat','Shan16SR3K.Cat','DMM','WhereFamilyLives','Clinical.Center','Clinical.Country','Continent','Sex','Gest.Age.Rough','BabysLengthCat','BabysWeightClass','ApgarClass','PreEclampsiaOrToxemia','Birth.Mode','Birth.Mode.Simple','Birth.Season','FdrName','HLA.CategoryLong','IA.OutcomeYesNo','T1D.OutcomeYesNo','ProbioticsFive','EverProbioticsYesNo','AbxTenState','AbxName','Amoxicillin','InfEpTen','InfEpTenFever','BothInfFev','SpecialDiets','JustCowsMilkAvoidance','JustVegetarian','JustCerealOrWheatAvoidanceOrGlutenFree','Breastfeeding','formula.any','first.form.process','formula.cows.milk','formula.soy','formula.probiotic','formula.prebiotic','apple.sauce.or.apple.juice','fruit.or.berries','potatoes','sweet.potatoes.or.yams','carrots','spinach','beets','peas.green.beans','turnip.parsnip.artichoke.rutabag','cabbages','squash.pumpkin','tomato.or.tomato.sauce','corn','other.vegetable','rice','wheat','barley','oat','rye','buckwheat.and.millet','other.fib01','other.fib02','other.fib03','other.fib04','other.fib05','other.fib06','other.fib07','other.fib08','other.fib09','other.fib10','other.fib11','other.fib12','other.fib13','pork.beef','poultry','other.kinds.of.meat','sausage.hot.dogs','fish.or.other.seafood','egg','milk.products','regular.cow.s.milk.or.ice.cream','commercial.baby.food.containing','soy.milk.and.other.soy.products','rice.milk','goat.milk','gluten','cereals','gluten.cereals','nongluten.cereals','noncorn.cereals','nongluten.noncorn.cereals','rice.ricemilk','fruits.and.berries','root.vegetables','total.roots','milk.product','cow.milk.any','soy','cow.milk.nof','fibtime','child.a1','child.a2','child.a3','child.a4','child.a5','child.a6','child.a7','child.a8','child.a9','child.a10','child.a11','child.a12','child.a13','child.a14','child.a15','child.a16','child.a17','child.a18','child.a19','child.a20','child.a21','child.a22','child.a23','child.a24','child.a25','child.a26','child.a27','child.b1','child.b2','child.b3','child.b4','child.b5','child.b6','child.b7','child.b8','child.b9','child.b10','random.Cat'),drop=FALSE], perm = 9999, na.rm = TRUE))
(fit2 <- envfit(custom_age_md[c('AvgCorrSorPCoA.Axis1','AvgCorrSorPCoA.Axis2')], custom_age_md[,c('mean.s.protein.Cat','mean.f.protein.Cat','mean.protein.Cat','mean.s.nitro.Cat','mean.f.nitro.Cat','mean.nitro.Cat','mean.s.fat.Cat','mean.f.fat.Cat','mean.fat.Cat','mean.s.safa.Cat','mean.f.safa.Cat','mean.safa.Cat','mean.s.butanoic.Cat','mean.f.butanoic.Cat','mean.butanoic.Cat','mean.s.hexanoic.Cat','mean.f.hexanoic.Cat','mean.hexanoic.Cat','mean.s.octanoic.Cat','mean.f.octanoic.Cat','mean.octanoic.Cat','mean.s.decanoic.Cat','mean.f.decanoic.Cat','mean.decanoic.Cat','mean.s.lauric.Cat','mean.f.lauric.Cat','mean.lauric.Cat','mean.s.myristic.Cat','mean.f.myristic.Cat','mean.myristic.Cat','mean.s.palmitic.Cat','mean.f.palmitic.Cat','mean.palmitic.Cat','mean.s.stearic.Cat','mean.f.stearic.Cat','mean.stearic.Cat','mean.s.arachidic.Cat','mean.f.arachidic.Cat','mean.arachidic.Cat','mean.s.mufa.Cat','mean.f.mufa.Cat','mean.mufa.Cat','mean.s.palmitoleic.Cat','mean.f.palmitoleic.Cat','mean.palmitoleic.Cat','mean.s.oleic.Cat','mean.f.oleic.Cat','mean.oleic.Cat','mean.s.pufa.Cat','mean.f.pufa.Cat','mean.pufa.Cat','mean.s.linoleic.Cat','mean.f.linoleic.Cat','mean.linoleic.Cat','mean.s.linolenic.Cat','mean.f.linolenic.Cat','mean.linolenic.Cat','mean.s.linolenic.n3.Cat','mean.f.linolenic.n3.Cat','mean.linolenic.n3.Cat','mean.s.arachidonic.Cat','mean.f.arachidonic.Cat','mean.arachidonic.Cat','mean.s.eico.Cat','mean.f.eico.Cat','mean.eico.Cat','mean.s.dpa.Cat','mean.f.dpa.Cat','mean.dpa.Cat','mean.s.dha.Cat','mean.f.dha.Cat','mean.dha.Cat','mean.s.chol.Cat','mean.f.chol.Cat','mean.chol.Cat','mean.s.carb.Cat','mean.f.carb.Cat','mean.carb.Cat','mean.s.sugar.Cat','mean.f.sugar.Cat','mean.sugar.Cat','mean.s.starch.Cat','mean.f.starch.Cat','mean.starch.Cat','mean.s.fiber.Cat','mean.f.fiber.Cat','mean.fiber.Cat','mean.s.betacar.Cat','mean.f.betacar.Cat','mean.betacar.Cat','mean.s.reteq.Cat','mean.f.reteq.Cat','mean.reteq.Cat','mean.s.retaeq.Cat','mean.f.retaeq.Cat','mean.retaeq.Cat','mean.s.vitd.Cat','mean.f.vitd.Cat','mean.vitd.Cat','mean.s.vite.Cat','mean.f.vite.Cat','mean.vite.Cat','mean.s.vite.tot.Cat','mean.f.vite.tot.Cat','mean.vite.tot.Cat','mean.s.vitk.Cat','mean.f.vitk.Cat','mean.vitk.Cat','mean.s.vitc.Cat','mean.f.vitc.Cat','mean.vitc.Cat','mean.s.thiamin.Cat','mean.f.thiamin.Cat','mean.thiamin.Cat','mean.s.riboflavin.Cat','mean.f.riboflavin.Cat','mean.riboflavin.Cat','mean.s.niacin.Cat','mean.f.niacin.Cat','mean.niacin.Cat','mean.s.folate.Cat','mean.f.folate.Cat','mean.folate.Cat','mean.s.pyridoxine.Cat','mean.f.pyridoxine.Cat','mean.pyridoxine.Cat','mean.s.pantothenic.Cat','mean.f.pantothenic.Cat','mean.pantothenic.Cat','mean.s.vitb12.Cat','mean.f.vitb12.Cat','mean.vitb12.Cat','mean.s.calcium.Cat','mean.f.calcium.Cat','mean.calcium.Cat','mean.s.phos.Cat','mean.f.phos.Cat','mean.phos.Cat','mean.s.potassium.Cat','mean.f.potassium.Cat','mean.potassium.Cat','mean.s.mag.Cat','mean.f.mag.Cat','mean.mag.Cat','mean.s.mang.Cat','mean.f.mang.Cat','mean.mang.Cat','mean.s.iron.Cat','mean.f.iron.Cat','mean.iron.Cat','mean.s.zinc.Cat','mean.f.zinc.Cat','mean.zinc.Cat','mean.s.copper.Cat','mean.f.copper.Cat','mean.copper.Cat','mean.energy.Cat'),drop=FALSE], perm = 9999, na.rm = TRUE))

(FungiPCoASor_Pvalue <- fit1$factors$pvals) #change all "factors" to "vectors" for continuous variables
(FungiPCoASor_PvalueFDR <- p.adjust(FungiPCoASor_Pvalue, method = "fdr"))
(FungiPCoASor_r2 <- fit1$factors$r)
write.table(FungiPCoASor_Pvalue, "/Users/tommyauchtung/Desktop/envfit/FungiPCoASor_Pvalue.txt", sep="\t")
write.table(FungiPCoASor_PvalueFDR, "/Users/tommyauchtung/Desktop/envfit/FungiPCoASor_PvalueFDR.txt", sep="\t")
write.table(FungiPCoASor_r2, "/Users/tommyauchtung/Desktop/envfit/FungiPCoASor_r2.txt", sep="\t")

(FungiPCoASor_Pvalue <- fit2$factors$pvals) #change all "factors" to "vectors" for continuous variables
(FungiPCoASor_PvalueFDR <- p.adjust(FungiPCoASor_Pvalue, method = "fdr"))
(FungiPCoASor_r2 <- fit2$factors$r)
write.table(FungiPCoASor_Pvalue, "/Users/tommyauchtung/Desktop/envfit/FungiPCoASor_Pvalue_2.txt", sep="\t")
write.table(FungiPCoASor_PvalueFDR, "/Users/tommyauchtung/Desktop/envfit/FungiPCoASor_PvalueFDR_2.txt", sep="\t")
write.table(FungiPCoASor_r2, "/Users/tommyauchtung/Desktop/envfit/FungiPCoASor_r2_2.txt", sep="\t")

############################## tSNE Envfit ################################
#tSNE Bray
#discrete variables
(fit1 <- envfit(custom_age_md[c('tSNEBray1','tSNEBray2')], custom_age_md[,c('ObsFungiR3K.Cat','ShanFungiR3K.Cat','Obs16SR3K.Cat','Shan16SR3K.Cat','DMM','WhereFamilyLives','Clinical.Center','Clinical.Country','Continent','Sex','Gest.Age.Rough','BabysLengthCat','BabysWeightClass','ApgarClass','PreEclampsiaOrToxemia','Birth.Mode','Birth.Mode.Simple','Birth.Season','FdrName','HLA.CategoryLong','ProbioticsFive','EverProbioticsYesNo','AbxTenState','AbxName','Amoxicillin','InfEpTen','InfEpTenFever','BothInfFev','SpecialDiets','JustCowsMilkAvoidance','JustVegetarian','JustCerealOrWheatAvoidanceOrGlutenFree','Breastfeeding','formula.any','first.form.process','formula.cows.milk','formula.soy','formula.probiotic','formula.prebiotic','apple.sauce.or.apple.juice','fruit.or.berries','potatoes','sweet.potatoes.or.yams','carrots','spinach','beets','peas.green.beans','turnip.parsnip.artichoke.rutabag','cabbages','squash.pumpkin','tomato.or.tomato.sauce','corn','other.vegetable','rice','wheat','barley','oat','rye','buckwheat.and.millet','other.fib01','other.fib02','other.fib03','other.fib04','other.fib05','other.fib06','other.fib07','other.fib08','other.fib09','other.fib10','other.fib11','other.fib12','other.fib13','pork.beef','poultry','other.kinds.of.meat','sausage.hot.dogs','fish.or.other.seafood','egg','milk.products','regular.cow.s.milk.or.ice.cream','commercial.baby.food.containing','soy.milk.and.other.soy.products','rice.milk','goat.milk','gluten','cereals','gluten.cereals','nongluten.cereals','noncorn.cereals','nongluten.noncorn.cereals','rice.ricemilk','fruits.and.berries','root.vegetables','total.roots','milk.product','cow.milk.any','soy','cow.milk.nof','fibtime','child.a1','child.a2','child.a3','child.a4','child.a5','child.a6','child.a7','child.a8','child.a9','child.a10','child.a11','child.a12','child.a13','child.a14','child.a15','child.a16','child.a17','child.a18','child.a19','child.a20','child.a21','child.a22','child.a23','child.a24','child.a25','child.a26','child.a27','child.b1','child.b2','child.b3','child.b4','child.b5','child.b6','child.b7','child.b8','child.b9','child.b10','DMM.16S','IA.OutcomeYesNoCorrected','T1D.OutcomeYesNoCorrected','DaysOnProbiotics','random.Cat'),drop=FALSE], perm = 9999, na.rm = TRUE))
#continuous variables
(fit2 <- envfit(custom_age_md[c('tSNEBray1','tSNEBray2')], custom_age_md[,c('mean.s.protein.Cat','mean.f.protein.Cat','mean.protein.Cat','mean.s.nitro.Cat','mean.f.nitro.Cat','mean.nitro.Cat','mean.s.fat.Cat','mean.f.fat.Cat','mean.fat.Cat','mean.s.safa.Cat','mean.f.safa.Cat','mean.safa.Cat','mean.s.butanoic.Cat','mean.f.butanoic.Cat','mean.butanoic.Cat','mean.s.hexanoic.Cat','mean.f.hexanoic.Cat','mean.hexanoic.Cat','mean.s.octanoic.Cat','mean.f.octanoic.Cat','mean.octanoic.Cat','mean.s.decanoic.Cat','mean.f.decanoic.Cat','mean.decanoic.Cat','mean.s.lauric.Cat','mean.f.lauric.Cat','mean.lauric.Cat','mean.s.myristic.Cat','mean.f.myristic.Cat','mean.myristic.Cat','mean.s.palmitic.Cat','mean.f.palmitic.Cat','mean.palmitic.Cat','mean.s.stearic.Cat','mean.f.stearic.Cat','mean.stearic.Cat','mean.s.arachidic.Cat','mean.f.arachidic.Cat','mean.arachidic.Cat','mean.s.mufa.Cat','mean.f.mufa.Cat','mean.mufa.Cat','mean.s.palmitoleic.Cat','mean.f.palmitoleic.Cat','mean.palmitoleic.Cat','mean.s.oleic.Cat','mean.f.oleic.Cat','mean.oleic.Cat','mean.s.pufa.Cat','mean.f.pufa.Cat','mean.pufa.Cat','mean.s.linoleic.Cat','mean.f.linoleic.Cat','mean.linoleic.Cat','mean.s.linolenic.Cat','mean.f.linolenic.Cat','mean.linolenic.Cat','mean.s.linolenic.n3.Cat','mean.f.linolenic.n3.Cat','mean.linolenic.n3.Cat','mean.s.arachidonic.Cat','mean.f.arachidonic.Cat','mean.arachidonic.Cat','mean.s.eico.Cat','mean.f.eico.Cat','mean.eico.Cat','mean.s.dpa.Cat','mean.f.dpa.Cat','mean.dpa.Cat','mean.s.dha.Cat','mean.f.dha.Cat','mean.dha.Cat','mean.s.chol.Cat','mean.f.chol.Cat','mean.chol.Cat','mean.s.carb.Cat','mean.f.carb.Cat','mean.carb.Cat','mean.s.sugar.Cat','mean.f.sugar.Cat','mean.sugar.Cat','mean.s.starch.Cat','mean.f.starch.Cat','mean.starch.Cat','mean.s.fiber.Cat','mean.f.fiber.Cat','mean.fiber.Cat','mean.s.betacar.Cat','mean.f.betacar.Cat','mean.betacar.Cat','mean.s.reteq.Cat','mean.f.reteq.Cat','mean.reteq.Cat','mean.s.retaeq.Cat','mean.f.retaeq.Cat','mean.retaeq.Cat','mean.s.vitd.Cat','mean.f.vitd.Cat','mean.vitd.Cat','mean.s.vite.Cat','mean.f.vite.Cat','mean.vite.Cat','mean.s.vite.tot.Cat','mean.f.vite.tot.Cat','mean.vite.tot.Cat','mean.s.vitk.Cat','mean.f.vitk.Cat','mean.vitk.Cat','mean.s.vitc.Cat','mean.f.vitc.Cat','mean.vitc.Cat','mean.s.thiamin.Cat','mean.f.thiamin.Cat','mean.thiamin.Cat','mean.s.riboflavin.Cat','mean.f.riboflavin.Cat','mean.riboflavin.Cat','mean.s.niacin.Cat','mean.f.niacin.Cat','mean.niacin.Cat','mean.s.folate.Cat','mean.f.folate.Cat','mean.folate.Cat','mean.s.pyridoxine.Cat','mean.f.pyridoxine.Cat','mean.pyridoxine.Cat','mean.s.pantothenic.Cat','mean.f.pantothenic.Cat','mean.pantothenic.Cat','mean.s.vitb12.Cat','mean.f.vitb12.Cat','mean.vitb12.Cat','mean.s.calcium.Cat','mean.f.calcium.Cat','mean.calcium.Cat','mean.s.phos.Cat','mean.f.phos.Cat','mean.phos.Cat','mean.s.potassium.Cat','mean.f.potassium.Cat','mean.potassium.Cat','mean.s.mag.Cat','mean.f.mag.Cat','mean.mag.Cat','mean.s.mang.Cat','mean.f.mang.Cat','mean.mang.Cat','mean.s.iron.Cat','mean.f.iron.Cat','mean.iron.Cat','mean.s.zinc.Cat','mean.f.zinc.Cat','mean.zinc.Cat','mean.s.copper.Cat','mean.f.copper.Cat','mean.copper.Cat','mean.energy.Cat','DaysOnProbiotics'),drop=FALSE], perm = 9999, na.rm = TRUE)) #May need to break this up and not run all at same time

(FungitSNEBray_Pvalue <- fit$factors$pvals) #discrete variables
(FungitSNEBray_PvalueFDR <- p.adjust(FungitSNEBray_Pvalue, method = "fdr"))
(FungitSNEBray_r2 <- fit$factors$r)
(FungitSNEBray_Pvalue2 <- fit2$vectors$pvals) #continuous variables
(FungitSNEBray_PvalueFDR2 <- p.adjust(FungitSNEBray_Pvalue2, method = "fdr"))
(FungitSNEBray_r22 <- fit2$vectors$r)

write.table(FungitSNEBray_Pvalue, "/Users/tommyauchtung/Desktop/envfit/FungitSNEBray_Pvalue.txt", sep="\t")
write.table(FungitSNEBray_PvalueFDR, "/Users/tommyauchtung/Desktop/envfit/FungitSNEBray_PvalueFDR.txt", sep="\t")
write.table(FungitSNEBray_r2, "/Users/tommyauchtung/Desktop/envfit/FungitSNEBray_r2.txt", sep="\t")
write.table(FungitSNEBray_Pvalue2, "/Users/tommyauchtung/Desktop/envfit/FungitSNEBray_Pvalue_2.txt", sep="\t")
write.table(FungitSNEBray_PvalueFDR2, "/Users/tommyauchtung/Desktop/envfit/FungitSNEBray_PvalueFDR2.txt", sep="\t")
write.table(FungitSNEBray_r22, "/Users/tommyauchtung/Desktop/envfit/FungitSNEBray_r22.txt", sep="\t")

#tSNE Sorensen
#discrete variables
(fit1 <- envfit(custom_age_md[c('tSNESor1','tSNESor2')], custom_age_md[,c('ObsFungiR3K.Cat','ShanFungiR3K.Cat','Obs16SR3K.Cat','Shan16SR3K.Cat','DMM','WhereFamilyLives','Clinical.Center','Clinical.Country','Continent','Sex','Gest.Age.Rough','BabysLengthCat','BabysWeightClass','ApgarClass','PreEclampsiaOrToxemia','Birth.Mode','Birth.Mode.Simple','Birth.Season','FdrName','HLA.CategoryLong','ProbioticsFive','EverProbioticsYesNo','AbxTenState','AbxName','Amoxicillin','InfEpTen','InfEpTenFever','BothInfFev','SpecialDiets','JustCowsMilkAvoidance','JustVegetarian','JustCerealOrWheatAvoidanceOrGlutenFree','Breastfeeding','formula.any','first.form.process','formula.cows.milk','formula.soy','formula.probiotic','formula.prebiotic','apple.sauce.or.apple.juice','fruit.or.berries','potatoes','sweet.potatoes.or.yams','carrots','spinach','beets','peas.green.beans','turnip.parsnip.artichoke.rutabag','cabbages','squash.pumpkin','tomato.or.tomato.sauce','corn','other.vegetable','rice','wheat','barley','oat','rye','buckwheat.and.millet','other.fib01','other.fib02','other.fib03','other.fib04','other.fib05','other.fib06','other.fib07','other.fib08','other.fib09','other.fib10','other.fib11','other.fib12','other.fib13','pork.beef','poultry','other.kinds.of.meat','sausage.hot.dogs','fish.or.other.seafood','egg','milk.products','regular.cow.s.milk.or.ice.cream','commercial.baby.food.containing','soy.milk.and.other.soy.products','rice.milk','goat.milk','gluten','cereals','gluten.cereals','nongluten.cereals','noncorn.cereals','nongluten.noncorn.cereals','rice.ricemilk','fruits.and.berries','root.vegetables','total.roots','milk.product','cow.milk.any','soy','cow.milk.nof','fibtime','child.a1','child.a2','child.a3','child.a4','child.a5','child.a6','child.a7','child.a8','child.a9','child.a10','child.a11','child.a12','child.a13','child.a14','child.a15','child.a16','child.a17','child.a18','child.a19','child.a20','child.a21','child.a22','child.a23','child.a24','child.a25','child.a26','child.a27','child.b1','child.b2','child.b3','child.b4','child.b5','child.b6','child.b7','child.b8','child.b9','child.b10','DMM.16S','IA.OutcomeYesNoCorrected','T1D.OutcomeYesNoCorrected','DaysOnProbiotics','random.Cat'),drop=FALSE], perm = 9999, na.rm = TRUE))
#continuous variables
(fit2 <- envfit(custom_age_md[c('tSNESor1','tSNESor2')], custom_age_md[,c('mean.s.protein.Cat','mean.f.protein.Cat','mean.protein.Cat','mean.s.nitro.Cat','mean.f.nitro.Cat','mean.nitro.Cat','mean.s.fat.Cat','mean.f.fat.Cat','mean.fat.Cat','mean.s.safa.Cat','mean.f.safa.Cat','mean.safa.Cat','mean.s.butanoic.Cat','mean.f.butanoic.Cat','mean.butanoic.Cat','mean.s.hexanoic.Cat','mean.f.hexanoic.Cat','mean.hexanoic.Cat','mean.s.octanoic.Cat','mean.f.octanoic.Cat','mean.octanoic.Cat','mean.s.decanoic.Cat','mean.f.decanoic.Cat','mean.decanoic.Cat','mean.s.lauric.Cat','mean.f.lauric.Cat','mean.lauric.Cat','mean.s.myristic.Cat','mean.f.myristic.Cat','mean.myristic.Cat','mean.s.palmitic.Cat','mean.f.palmitic.Cat','mean.palmitic.Cat','mean.s.stearic.Cat','mean.f.stearic.Cat','mean.stearic.Cat','mean.s.arachidic.Cat','mean.f.arachidic.Cat','mean.arachidic.Cat','mean.s.mufa.Cat','mean.f.mufa.Cat','mean.mufa.Cat','mean.s.palmitoleic.Cat','mean.f.palmitoleic.Cat','mean.palmitoleic.Cat','mean.s.oleic.Cat','mean.f.oleic.Cat','mean.oleic.Cat','mean.s.pufa.Cat','mean.f.pufa.Cat','mean.pufa.Cat','mean.s.linoleic.Cat','mean.f.linoleic.Cat','mean.linoleic.Cat','mean.s.linolenic.Cat','mean.f.linolenic.Cat','mean.linolenic.Cat','mean.s.linolenic.n3.Cat','mean.f.linolenic.n3.Cat','mean.linolenic.n3.Cat','mean.s.arachidonic.Cat','mean.f.arachidonic.Cat','mean.arachidonic.Cat','mean.s.eico.Cat','mean.f.eico.Cat','mean.eico.Cat','mean.s.dpa.Cat','mean.f.dpa.Cat','mean.dpa.Cat','mean.s.dha.Cat','mean.f.dha.Cat','mean.dha.Cat','mean.s.chol.Cat','mean.f.chol.Cat','mean.chol.Cat','mean.s.carb.Cat','mean.f.carb.Cat','mean.carb.Cat','mean.s.sugar.Cat','mean.f.sugar.Cat','mean.sugar.Cat','mean.s.starch.Cat','mean.f.starch.Cat','mean.starch.Cat','mean.s.fiber.Cat','mean.f.fiber.Cat','mean.fiber.Cat','mean.s.betacar.Cat','mean.f.betacar.Cat','mean.betacar.Cat','mean.s.reteq.Cat','mean.f.reteq.Cat','mean.reteq.Cat','mean.s.retaeq.Cat','mean.f.retaeq.Cat','mean.retaeq.Cat','mean.s.vitd.Cat','mean.f.vitd.Cat','mean.vitd.Cat','mean.s.vite.Cat','mean.f.vite.Cat','mean.vite.Cat','mean.s.vite.tot.Cat','mean.f.vite.tot.Cat','mean.vite.tot.Cat','mean.s.vitk.Cat','mean.f.vitk.Cat','mean.vitk.Cat','mean.s.vitc.Cat','mean.f.vitc.Cat','mean.vitc.Cat','mean.s.thiamin.Cat','mean.f.thiamin.Cat','mean.thiamin.Cat','mean.s.riboflavin.Cat','mean.f.riboflavin.Cat','mean.riboflavin.Cat','mean.s.niacin.Cat','mean.f.niacin.Cat','mean.niacin.Cat','mean.s.folate.Cat','mean.f.folate.Cat','mean.folate.Cat','mean.s.pyridoxine.Cat','mean.f.pyridoxine.Cat','mean.pyridoxine.Cat','mean.s.pantothenic.Cat','mean.f.pantothenic.Cat','mean.pantothenic.Cat','mean.s.vitb12.Cat','mean.f.vitb12.Cat','mean.vitb12.Cat','mean.s.calcium.Cat','mean.f.calcium.Cat','mean.calcium.Cat','mean.s.phos.Cat','mean.f.phos.Cat','mean.phos.Cat','mean.s.potassium.Cat','mean.f.potassium.Cat','mean.potassium.Cat','mean.s.mag.Cat','mean.f.mag.Cat','mean.mag.Cat','mean.s.mang.Cat','mean.f.mang.Cat','mean.mang.Cat','mean.s.iron.Cat','mean.f.iron.Cat','mean.iron.Cat','mean.s.zinc.Cat','mean.f.zinc.Cat','mean.zinc.Cat','mean.s.copper.Cat','mean.f.copper.Cat','mean.copper.Cat','mean.energy.Cat','DaysOnProbiotics'),drop=FALSE], perm = 9999, na.rm = TRUE))

(FungitSNESor_Pvalue <- fit$factors$pvals) #discrete variables
(FungitSNESor_PvalueFDR <- p.adjust(FungitSNESor_Pvalue, method = "fdr"))
(FungitSNESor_r2 <- fit$factors$r)
(FungitSNESor_Pvalue2 <- fit2$vectors$pvals) #continuous variables
(FungitSNESor_PvalueFDR2 <- p.adjust(FungitSNESor_Pvalue2, method = "fdr"))
(FungitSNESor_r22 <- fit2$vectors$r)

write.table(FungitSNESor_Pvalue, "/Users/tommyauchtung/Desktop/envfit/FungitSNESor_Pvalue.txt", sep="\t")
write.table(FungitSNESor_PvalueFDR, "/Users/tommyauchtung/Desktop/envfit/FungitSNESor_PvalueFDR.txt", sep="\t")
write.table(FungitSNESor_r2, "/Users/tommyauchtung/Desktop/envfit/FungitSNESor_r2.txt", sep="\t")
write.table(FungitSNESor_Pvalue2, "/Users/tommyauchtung/Desktop/envfit/FungitSNESor_Pvalue_2.txt", sep="\t")
write.table(FungitSNESor_PvalueFDR2, "/Users/tommyauchtung/Desktop/envfit/FungitSNESor_PvalueFDR2.txt", sep="\t")
write.table(FungitSNESor_r22, "/Users/tommyauchtung/Desktop/envfit/FungitSNESor_r22.txt", sep="\t")

#Put resulting files together using paste, cut, and cat